@@ -5,7 +5,17 @@ import datetime
 import aiosqlite
 
 
+print("""
+===========================================================================================
 
+ DPYS is a really good library if you know how to use it.
+
+-------------------------------------------------------------------------------------------
+
+ We recommend that you read https://sites.google.com/view/dpys before you use the library.
+ 
+===========================================================================================
+""")
 async def reload(bat, dir, client):
     os.chdir(dir)
     os.startfile(bat)
@@ -106,13 +116,13 @@ class curse():
                 word = word.lower()
                 word = word.replace(" ", "")
                 word = word.split(",")
-                in_db = False
                 async with db.execute("SELECT curse FROM curses WHERE guild = ?", (guildid,)) as cursor:
+                    in_db = False
                     async for entry in cursor:
                         curse = entry[0]
                         for x in word:
                             if x == curse:
-                             in_db = True
+                                in_db = True
                 if in_db == False:
                     if len(word) > 1:
                         await ctx.send("None of those words are in the list", delete_after=5)
